@@ -1,6 +1,6 @@
 package Bot::Backbone::Service::JabberChat;
 BEGIN {
-  $Bot::Backbone::Service::JabberChat::VERSION = '0.112400';
+  $Bot::Backbone::Service::JabberChat::VERSION = '0.112500';
 }
 use v5.10;
 use Moose;
@@ -120,15 +120,15 @@ has session_ready => (
 );
 
 
-has group_names => (
+has group_options => (
     is          => 'rw',
-    isa         => 'ArrayRef[Str]',
+    isa         => 'ArrayRef[HashRef]',
     required    => 1,
     default     => sub { [] },
     traits      => [ 'Array' ],
     handles     => {
-        all_group_names => 'elements',
-        add_group_name  => 'push',
+        all_group_options => 'elements',
+        add_group_options => 'push',
     },
 );
 
@@ -225,33 +225,37 @@ sub initialize {
 sub _join_pending_groups {
     my $self = shift;
 
-    # Perform join from either the params or list of group names
-    my @pending_group_names;
+    # Perform join from either the params or list of group options
+    my @pending_group_options;
     if (@_) {
-        @pending_group_names = @_;
+        @pending_group_options = @_;
     }
     else {
-        @pending_group_names = $self->all_group_names;
+        @pending_group_options = $self->all_group_options;
     }
 
     my $account = $self->xmpp_account;
     my $conn    = $self->xmpp_connection;
 
     # Join each group requested
-    for my $group_name (@pending_group_names) {
+    for my $group_options (@pending_group_options) {
+        my $nickname = $account->nickname_for_jid($self->jid);
+        $nickname = $group_options->{nickname}
+            if defined $group_options->{nickname};
+
         $self->xmpp_muc->join_room(
             $conn,
-            $self->group_jid($group_name),
-            $account->nickname_for_jid($self->jid),
+            $self->group_jid($group_options->{group}),
+            $nickname,
         );
     }
 }
 
 sub join_group {
-    my ($self, $name) = @_;
+    my ($self, $options) = @_;
 
-    $self->add_group_name($name);
-    $self->_join_pending_groups($name) if $self->session_ready;
+    $self->add_group_options($options);
+    $self->_join_pending_groups($options) if $self->session_ready;
 }
 
 
@@ -383,7 +387,7 @@ Bot::Backbone::Service::JabberChat - Connect and chat with a Jabber server
 
 =head1 VERSION
 
-version 0.112400
+version 0.112500
 
 =head1 SYNOPSIS
 
@@ -454,7 +458,7 @@ This is the XMPP multi-user chat extension helper.
 Once the connection has been made and is ready to start sending and receiving
 messages, this will be set to true.
 
-=head2 group_names
+=head2 group_options
 
 This is a list of multi-user chat groups the bot has joined or intends to join
 once L</session_ready> becomes true.
