@@ -1,6 +1,6 @@
 package Bot::Backbone::Service::Role::GroupJoiner;
 BEGIN {
-  $Bot::Backbone::Service::Role::GroupJoiner::VERSION = '0.112400';
+  $Bot::Backbone::Service::Role::GroupJoiner::VERSION = '0.112500';
 }
 use v5.10;
 use Moose::Role;
@@ -21,7 +21,7 @@ Bot::Backbone::Service::Role::GroupJoiner - Chat services that can join a chat g
 
 =head1 VERSION
 
-version 0.112400
+version 0.112500
 
 =head1 DESCRIPTION
 
@@ -31,10 +31,24 @@ This is only useful to chat services (probably).
 
 =head2 join_group
 
-  $chat->join_group('foo');
+  $chat->join_group(\%options);
 
-Given the name of a group to join, this performs the operations required to join
-the group.
+This method will cause the service to join the group described by the options in
+the way described by the options. Generally, the options will include (but are
+not limited to and all of these might not be supported):
+
+=over
+
+=item group
+
+This is the name of the group to join. Every implementation must support this
+option.
+
+=item nickname
+
+This is the nickname to give the bot within this group.
+
+=back
 
 =head1 AUTHOR
 
